@@ -91,7 +91,7 @@
 #' # Should be run many more `times` for publication-ready results
 #' tidy(model1)
 #' glance(model1)
-#' plot(model1)
+#' # if(require("autograph")) plot(model1)
 #' @export
 net_regression <- function(formula, .data,
                         method = c("qap","qapy"),
@@ -305,7 +305,9 @@ convertToMatrixList <- function(formula, .data){
           if(length(levels(fct)) == 2){
             out <- matrix(as.numeric(fct)-1,
                           nrow(DV), ncol(DV))
-            names(out) <- paste(IV[[elem]], collapse = " ")
+            names(out) <- paste(paste(IV[[elem]], collapse = " "),
+                                levels(fct)[2],
+                                paste0("[",levels(fct)[1],"]"))
             out <- out
           } else {
             out <- lapply(2:length(levels(fct)),
@@ -331,7 +333,9 @@ convertToMatrixList <- function(formula, .data){
             if(length(levels(fct)) == 2){
               out <- matrix(as.numeric(fct)-1,
                             nrow(DV), ncol(DV))
-              names(out) <- paste(IV[[elem]], collapse = " ")
+              names(out) <- paste(paste(IV[[elem]], collapse = " "),
+                                  levels(fct)[2],
+                                  paste0("[",levels(fct)[1],"]"))
               out <- out
             } else {
               out <- lapply(2:length(levels(fct)),
@@ -361,6 +365,7 @@ convertToMatrixList <- function(formula, .data){
                                    nrow(DV), ncol(DV)-1, byrow = TRUE))/
                 rowSums(net)
             }, FUN.VALUE = numeric(nrow(DV)))
+            out[is.nan(out)] <- 0
           } else { # or then attrib must be on first mode
             attrib <- attrib[!manynet::node_is_mode(.data)]
             out <- t(vapply(1:length(attrib), function(x){
@@ -369,6 +374,7 @@ convertToMatrixList <- function(formula, .data){
                                    nrow(DV)-1, ncol(DV)))/
                 colSums(net)
             }, FUN.VALUE = numeric(ncol(DV))))
+            out[is.nan(out)] <- 0
           }
         } else {
           rows <- matrix(attrib, nrow(DV), ncol(DV))
